@@ -19,6 +19,21 @@
 
 import logging
 import ldap
+import getpass
+
+def start_ldap_session(server, binddn):
+    """ Initiate the LDAP session  """
+    ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_NEVER)
+    ldap.set_option(ldap.OPT_PROTOCOL_VERSION, ldap.VERSION3)
+    l = ldap.initialize(server, bytes_mode=False)
+    l.set_option(ldap.OPT_REFERRALS, 0)
+
+    creds = getpass.getpass('\nPlease, enter LDAP credentials for {}: '.format(binddn))
+    lsession = l.simple_bind_s(binddn, creds)
+    if lsession:
+        logging.info("\nSuccessful LDAP authentication!\n")
+    return l
+
 
 def ask_user_confirmation():
     """ Ask for user confirmation """
@@ -38,3 +53,13 @@ def retrieve_attrs_from_dn(ldap_session, basedn):
     ldap_data = ldap_session.search_s(basedn, ldap.SCOPE_BASE, 'objectClass=*')
     attrs = [i[1] for i in ldap_data]
     return attrs
+
+
+def ldap_delete_single_dn(ldap_session, delete_dn):
+    """ Delete a single LDAP entry based on its DN """
+    logging.info("\nWARNING: you are about to delete the " \
+    "following LDAP entry:\n\n %s\n", delete_dn)
+    if ask_user_confirmation():
+        ldap_session.delete_s(delete_dn)
+        logging.info("\nSuccessfully removed LDAP entry: %s\n", delete_dn)
+
